(function () {
  'use strict';

  const SHORT_MAX = 2;     // ≤ 2 minutes
  const LONG_MIN = 11;     // ≥ 11 minutes

  function parseMinutes(el) {
    if (!el) return null;
    const m = el.textContent.match(/(\d+)\s*minute/);
    return m ? parseInt(m[1], 10) : null;
  }

  function stylize(entry, opts) {
    Object.assign(entry.style, {
      backgroundColor: opts.bg,
      border: `1px solid ${opts.border}`,
      borderRadius: '4px',
      padding: '5px',
      transition: 'border-color .5s ease, box-shadow .5s ease',
    });
    entry.addEventListener('mouseover', () => {
      entry.style.borderColor = opts.hoverBorder;
      entry.style.boxShadow = `0 0 10px ${opts.hoverGlow}`;
    });
    entry.addEventListener('mouseout', () => {
      entry.style.borderColor = opts.border;
      entry.style.boxShadow = 'none';
    });
  }

  document.querySelectorAll('article.item.entry-item').forEach(entry => {
    const mins = parseMinutes(entry.querySelector('.item-meta-info-reading-time span'));
    if (mins === null) return;
    if (mins <= SHORT_MAX) {
      stylize(entry, {
        bg: 'rgb(37, 44, 39)',
        border: 'rgb(79, 194, 20)',
        hoverBorder: 'rgb(129, 255, 50)',
        hoverGlow: 'rgba(129, 255, 50, .8)',
      });
      entry.dataset.readCategory = 'short';
    } else if (mins >= LONG_MIN) {
      stylize(entry, {
        bg: 'rgb(44, 39, 37)',
        border: 'rgb(194, 79, 20)',
        hoverBorder: 'rgb(255, 129, 50)',
        hoverGlow: 'rgba(255, 129, 50, .8)',
      });
      entry.dataset.readCategory = 'long';
    }
  });

  function addFilter(label, category) {
    const nav = document.querySelector('.page-header nav ul');
    const entries = document.querySelectorAll('article.item.entry-item');
    if (!nav || entries.length === 0) return;   // no content -> no button

    const mapping = {
      short: { border: 'rgb(79, 194, 20)', bg: 'rgb(37, 44, 39)' },
      long:  { border: 'rgb(194, 79, 20)', bg: 'rgb(44, 39, 37)' },
      all:   { border: '#ccc',             bg: '#ccc'       },
    };
    const m = mapping[category];

    const btn = document.createElement('button');
    btn.textContent = `Filter: ${label}`;
    Object.assign(btn.style, {
      marginLeft: '10px',
      padding: '5px 10px',
      border: `1px solid ${m.border}`,
      borderRadius: '5px',
      backgroundColor: m.bg,
      color: category === 'all' ? '#000' : '#fff',
      cursor: 'pointer',
    });
    btn.addEventListener('mouseover', () => {
      btn.style.borderColor = category === 'all' ? '#999' : m.border;
    });
    btn.addEventListener('mouseout', () => {
      btn.style.borderColor = m.border;
    });
    btn.onclick = () => {
      entries.forEach(e => {
        e.style.display = (category === 'all' || e.dataset.readCategory === category) ? '' : 'none';
      });
    };
    nav.appendChild(btn);
  }

  document.addEventListener('DOMContentLoaded', () => {
    addFilter('Short Reads', 'short');
    addFilter('Long Reads', 'long');
    addFilter('All', 'all');
  });
})();
